@@ -7,7 +7,7 @@ Created on 2013-3-22
 @author: stone
 '''
 
-from pdbx import Rpdb
+from pdbx import Rpdb, enable_pystack
 import random
 import time
 
@@ -16,7 +16,7 @@ def add(i, j):
     r = i + j
     return r
 
-def main():
+def rpdb():
     rpdb = Rpdb()                # Debugger started. Port is 8787(Default Value),   Suspend is True(Default Value)
     # rpdb = Rpdb(9898)          # Debugger started. Port is 9898(Specified Value), Suspend is True(Default Value)
     # rpdb = Rpdb(suspend=False) # Debugger started. Port is 8787(Default Value),   Suspend is False(Specified Value) 
@@ -29,5 +29,10 @@ def main():
         print r
         time.sleep(1)
 
+def pystack():
+    enable_pystack()
+
 if __name__ == '__main__':
-    main()
+    #main()
+    enable_pystack()
+    time.sleep(100000)
